#
# spec file for package gnash
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 p.drouand@gmail.com
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via packman@links2linux.de

%bcond_without distributable

Name:           gnash
Version:        0.8.11+git20120706
%define tag     0.8.11dev
Release:        1.30
License:        GPL-2.0+
%define cvs_date 0
BuildRequires:  SDL-devel
BuildRequires:  agg-devel
BuildRequires:  boost-devel
BuildRequires:  curl-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  gstreamer-0_10-plugins-base-devel
BuildRequires:  gstreamer010-devel
BuildRequires:  gtk2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  speex-devel
%if 0%{?suse_version} >= 1210
BuildRequires:	pkgconfig(gconf-2.0)
%else
BuildRequires:  gconf2-devel
%endif
%if 0%{?suse_version} >= 1210
BuildRequires:	xulrunner-devel
%else
BuildRequires:  mozilla-xulrunner20-devel
%endif
%if !%{with distributable}
BuildRequires:  libffmpeg_oldabi-devel
Requires:	    gnash-common = %{version}
%endif
BuildRequires:  update-desktop-files
Summary:        Standalone GTK+-based player that use AGG as the rendering backend
Group:          Productivity/Networking/Web/Browsers
%if %{cvs_date}
%define package_version %{version}.cvs%{cvs_date}
%else
%define package_version %{version}
%endif
Url:            http://www.gnu.org/software/gnash/
Source:         gnash-0.8.11%2Bgit20120706.tar.bz2
#Source1:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM gnash-0.8.5-build-fixes.diff
#Patch:          gnash-0.8.5-build-fixes.diff
#Patch1:         gnash-fix-insecure-temp-files.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gnash is a Free Flash movie player, which works either standalone, or
as a Firefox/Mozilla plugin.

Gnash supports the current Shockwave format, version 7. While all the
ActionScript classes exist, not all of the methods defined by the SWF
format documentation are implemented however, so not all flash movies
work 100% if they utilize any of the unimplemented methods. This is one
of the areas to work on to achieve full version 7 compliance.

%package devel
License:        GPLv2+
Summary:        Gnash include files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Include files for developing with gnash.

%package browser-plugin
Summary:	Contain Mozilla/Firefox plug-in
Group:		Productivity/Networking/Web/Browsers
Requires:	gnash-common = %{version}

%description browser-plugin
Contain Mozilla/Firefox plug-in.
Works with Firefox 1.0.4 and newer and theoretically with all Mozilla-based Webbrowser

%package common
Summary:	Common files for Gnash packages
Group:		Productivity/Networking/Web/Browsers

%description common
This package contains common files of all Gnash packages

%package common-lang
Summary:    Languages for package %{name}-common
Group:      System/Localization
Requires:   %{name}-common = %{version}
Provides:   %{name}-common-lang-all = %{version}
Supplements: packageand(bundle-lang-other:%{name}-common)
BuildArch:  noarch
%description common-lang
Provides translations to the package %{name}-common

%package tools
Summary:	Command-line utilities based in Gnash
Group:		Productivity/Networking/Web/Browsers
Requires:	gnash-common = %{version}

%description tools
This package includes command-line utilities based in Gnash.

%package doc
Summary:	API documentation
Group:		Productivity/Networking/Web/Browsers
BuildArch:  noarch

%description doc
Contains documentation for Gnash

%prep
%if %{cvs_date}
%setup -q -n gnash
# exclude movies.all
for i in configure.ac testsuite/Makefile.am; do
  grep -v 'movies\.all' $i > $i.x
  mv $i.x $i
done
%else
%setup -q -n gnash-%{version}
%endif
#%patch -p1
#%patch1 -p1

%build
autoreconf -fi
# -fpermissive is for broken boost with gcc-4.3 (#353897)
#  -fpermissive
CXXFLAGS="%{optflags}" \
%configure \
  --disable-static \
  --disable-ltdl-install \
  --disable-rpath \
  --enable-gui=gtk \
  --enable-renderer=agg \
%if %{with distributable}
  --enable-media=GST \
%else
  --enable-media=ffmpeg \
%endif
%if %suse_version < 1030
  --with-gstreamer-lib=/opt/gnome/%{_lib} \
%endif
  --with-plugins-install=system \
  --with-npapi-plugindir=%{_libdir}/browser-plugins

make %{?_smp_flags} VERBOSE=1 V=1

%install
%makeinstall install-plugins
find %{buildroot}%{_libdir} -name '*.la' -delete
# move/install documents
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/gnash %{buildroot}%{_docdir}
install -c -m 0644 AUTHORS COPYING ChangeLog* NEWS README TODO \
  %{buildroot}%{_docdir}/gnash

%suse_update_desktop_file -r gnash AudioVideo Player

%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}/locale

%clean
%{?buildroot:%__rm -rf '%{buildroot}'}

%files
%defattr(-, root, root)
%{_bindir}/gtk-gnash
%{_bindir}/gnash-gtk-launcher
%config(noreplace) %{_sysconfdir}/gnashrc
%{_datadir}/applications/gnash.desktop

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/pkgconfig/*.pc
%{_libdir}/%{name}/libgnashbase-%{tag}.so
%{_libdir}/%{name}/libgnashcore-%{tag}.so
%{_libdir}/%{name}/libgnashmedia-%{tag}.so
%{_libdir}/%{name}/libgnashrender-%{tag}.so
%{_libdir}/%{name}/libgnashsound-%{tag}.so
%{_libdir}/%{name}/libgnashdevice-%{tag}.so

%files common
%defattr(-,root,root)
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libgnashbase.so
%{_libdir}/%{name}/libgnashcore.so
%{_libdir}/%{name}/libgnashmedia.so
%{_libdir}/%{name}/libgnashrender.so
%{_libdir}/%{name}/libgnashdevice.so
%{_libdir}/%{name}/libgnashsound.so
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/GnashG.png
%{_datadir}/%{name}/gnash-splash.swf
%{_datadir}/%{name}/gnash_128_96.ico
%{_datadir}/icons/*/*/apps/gnash.*

%files common-lang -f %{name}.lang
%defattr(-,root,root)

%files browser-plugin
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/gnashpluginrc
%{_libdir}/browser-plugins/libgnashplugin.so

%files tools
%defattr(-,root,root)
%if %{with distributable}
# only available when built with gstreamer:
%{_bindir}/findmicrophones
%{_bindir}/findwebcams
%endif
%{_bindir}/gprocessor
%{_bindir}/rtmpget

%files doc
%defattr(-,root,root)
%doc %{_mandir}/man?/*
%if !%{with distributable}
%exclude %{_mandir}/man?/findmicrophones*
%exclude %{_mandir}/man?/findwebcams*
%endif
%doc %{_docdir}/gnash

%changelog
